==> flutter_getitpayment-0.0.3.tar.gz: lib/src/animateText.dart <==
import 'dart:async';

import 'package:flutter/material.dart';

class AnimateText extends StatefulWidget {
  final Widget child;
  final int delay;
  final bool changeDirection;
  AnimateText(
      {required this.child,
        required this.delay,
        required this.changeDirection});
  @override
  _AnimateTextState createState() => _AnimateTextState();
}

class _AnimateTextState extends State<AnimateText>
    with TickerProviderStateMixin {
  late AnimationController _animController;
  late Animation<Offset> _animOffset;
  @override
  Widget build(BuildContext context) {
    return FadeTransition(
      child: SlideTransition(
        position: _animOffset,
        child: widget.child,
      ),
      opacity: _animController,
    );
  }

  void reversAnim() async {
    await _animController.animateBack(0,
        curve: Curves.decelerate, duration: Duration(milliseconds: 300));
  }

  @override
  void initState() {
    super.initState();
    _animController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 300));
    final CurvedAnimation curve =
    CurvedAnimation(curve: Curves.decelerate, parent: _animController);
    _animOffset = Tween<Offset>(
        begin: widget.changeDirection
            ? const Offset(0.35, 0.0)
            : const Offset(0.0, 0.35),
        end: Offset.zero)
        .animate(curve);

    if (widget.delay == null) {
      _animController.forward();
    } else {
      Timer(Duration(milliseconds: widget.delay), () {
        try {
          _animController.forward();
        } catch (e) {}
      });
    }
  }

  @override
  void dispose() {
    _animController.dispose();
    super.dispose();
  }
}

==> flutter_getitpayment-0.1.5.tar.gz: lib/src/animateText.dart <==
import 'dart:async';

import 'package:flutter/material.dart';

class AnimateText extends StatefulWidget {
  final Widget child;
  final int? delay;
  final bool changeDirection;
  AnimateText(
      {required this.child,
        required this.delay,
        required this.changeDirection});
  @override
  _AnimateTextState createState() => _AnimateTextState();
}

class _AnimateTextState extends State<AnimateText>
    with TickerProviderStateMixin {
  late AnimationController _animController;
  late Animation<Offset> _animOffset;
  @override
  Widget build(BuildContext context) {
    return FadeTransition(
      child: SlideTransition(
        position: _animOffset,
        child: widget.child,
      ),
      opacity: _animController,
    );
  }

  void reversAnim() async {
    await _animController.animateBack(0,
        curve: Curves.decelerate, duration: Duration(milliseconds: 300));
  }

  @override
  void initState() {
    super.initState();
    _animController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 300));
    final CurvedAnimation curve =
    CurvedAnimation(curve: Curves.decelerate, parent: _animController);
    _animOffset = Tween<Offset>(
        begin: widget.changeDirection
            ? const Offset(0.35, 0.0)
            : const Offset(0.0, 0.35),
        end: Offset.zero)
        .animate(curve);

    if (widget.delay == null) {
      _animController.forward();
    } else {
      Timer(Duration(milliseconds: widget.delay!), () {
        try {
          _animController.forward();
        } catch (e) {}
      });
    }
  }

  @override
  void dispose() {
    _animController.dispose();
    super.dispose();
  }
}
